@@ -14,7 +14,6 @@ http://www.apache.org/licenses/LICENSE-2.0
 
 from __future__ import annotations
 
-import collections.abc
 import functools
 import inspect
 import logging
@@ -29,22 +28,12 @@ from ..feature import Feature
 from ..module import Module
 from ..modulemapping import ModuleMapping, ModuleName
 from ..protocol import BaseProtocol
-from .iotmodule import IotModule
+from .iotmodule import IotModule, merge
 from .modules import Emeter
 
 _LOGGER = logging.getLogger(__name__)
 
 
-def merge(d, u):
-    """Update dict recursively."""
-    for k, v in u.items():
-        if isinstance(v, collections.abc.Mapping):
-            d[k] = merge(d.get(k, {}), v)
-        else:
-            d[k] = v
-    return d
-
-
 def requires_update(f):
     """Indicate that `update` should be called before accessing this method."""  # noqa: D202
     if inspect.iscoroutinefunction(f):
@@ -209,7 +198,7 @@ class IotDevice(Device):
     def add_module(self, name: str | ModuleName[Module], module: IotModule):
         """Register a module."""
         if name in self._modules:
-            _LOGGER.debug("Module %s already registered, ignoring..." % name)
+            _LOGGER.debug("Module %s already registered, ignoring...", name)
             return
 
         _LOGGER.debug("Adding module %s", module)
@@ -382,7 +371,7 @@ class IotDevice(Device):
         est_response_size = 1024 if "system" in req else 0
         for module in self._modules.values():
             if not module.is_supported:
-                _LOGGER.debug("Module %s not supported, skipping" % module)
+                _LOGGER.debug("Module %s not supported, skipping", module)
                 continue
 
             est_response_size += module.estimated_query_response_size
@@ -572,6 +561,13 @@ class IotDevice(Device):
         """
         await self._query_helper("system", "reboot", {"delay": delay})
 
+    async def factory_reset(self) -> None:
+        """Reset device back to factory settings.
+
+        Note, this does not downgrade the firmware.
+        """
+        await self._query_helper("system", "reset")
+
     async def turn_off(self, **kwargs) -> dict:
         """Turn off the device."""
         raise NotImplementedError("Device subclass needs to implement this.")
