@@ -481,7 +481,7 @@ def _get_subclasses(of_class):
                 and name != "_deprecated_TPLinkSmartHomeProtocol"
             ):
                 subclasses.add((name, obj))
-    return subclasses
+    return sorted(subclasses)
 
 
 @pytest.mark.parametrize(
